@@ -12,7 +12,6 @@
 # limitations under the License.
 
 import os
-import uuid
 
 from pifpaf import drivers
 from pifpaf.drivers import gnocchi
@@ -22,24 +21,23 @@ from pifpaf.drivers import postgresql
 class AodhDriver(drivers.Driver):
 
     DEFAULT_PORT = 8042
+    DEFAULT_DB_DRIVER = "postgresql"
     DEFAULT_PORT_DB = 8050
     DEFAULT_PORT_GNOCCHI = 8051
     DEFAULT_PORT_GNOCCHI_INDEXER = 8052
 
     def __init__(self, port=DEFAULT_PORT,
                  database_port=DEFAULT_PORT_DB,
+                 database_url=None,
                  gnocchi_port=DEFAULT_PORT_GNOCCHI,
                  gnocchi_indexer_port=DEFAULT_PORT_GNOCCHI_INDEXER,
-                 gnocchi_create_legacy_resource_types=False,
                  **kwargs):
         super(AodhDriver, self).__init__(**kwargs)
         self.port = port
+        self.database_url = database_url
         self.database_port = database_port
         self.gnocchi_port = gnocchi_port
         self.gnocchi_indexer_port = gnocchi_indexer_port
-        self.gnocchi_create_legacy_resource_types = (
-            gnocchi_create_legacy_resource_types
-        )
 
     @classmethod
     def get_parser(cls, parser):
@@ -47,6 +45,7 @@ class AodhDriver(drivers.Driver):
                             type=int,
                             default=cls.DEFAULT_PORT,
                             help="port to use for Aodh")
+        parser.add_argument("--database-url", help="database URL to use")
         parser.add_argument("--database-port",
                             type=int,
                             default=cls.DEFAULT_PORT_DB,
@@ -59,43 +58,32 @@ class AodhDriver(drivers.Driver):
                             type=int,
                             default=cls.DEFAULT_PORT_GNOCCHI_INDEXER,
                             help="port to use for Gnocchi indexer")
-        parser.add_argument(
-            "--gnocchi-create-legacy-resource-types",
-            action='store_true',
-            default=False,
-            help="create legacy Ceilometer resource types in Gnocchi")
         return parser
 
     def _setUp(self):
         super(AodhDriver, self)._setUp()
 
-        pg = self.useFixture(
-            postgresql.PostgreSQLDriver(port=self.database_port))
+        if self.database_url is None:
+            pg = self.useFixture(
+                postgresql.PostgreSQLDriver(port=self.database_port))
+            self.database_url = pg.url
 
         g = self.useFixture(gnocchi.GnocchiDriver(
             port=self.gnocchi_port,
             indexer_port=self.gnocchi_indexer_port,
-            create_legacy_resource_types=(
-                self.gnocchi_create_legacy_resource_types
-            ),
         ))
 
         conffile = os.path.join(self.tempdir, "aodh.conf")
 
-        user = str(uuid.uuid4())
-        project = str(uuid.uuid4())
-
         with open(conffile, "w") as f:
             f.write("""[database]
 connection = %s
 [api]
 auth_mode=
 [service_credentials]
-auth_type = gnocchi-noauth
-user_id = %s
-project_id = %s
-roles = admin
-endpoint = %s""" % (pg.url, user, project, g.http_url))
+auth_type = gnocchi-basic
+user = admin
+endpoint = %s""" % (self.database_url, g.http_url))
 
         self._exec(["aodh-dbsync", "--config-file=%s" % conffile])
 
@@ -110,8 +98,7 @@ endpoint = %s""" % (pg.url, user, project, g.http_url))
         self.addCleanup(self._kill, c.pid)
 
         self.putenv("AODH_PORT", str(self.port))
-        self.putenv("AODH_GNOCCHI_USER_ID", user)
-        self.putenv("AODH_GNOCCHI_PROJECT_ID", project)
+        self.putenv("AODH_GNOCCHI_USER", "admin")
         self.putenv("URL", "aodh://localhost:%d" % self.port)
         url = "http://localhost:%d" % self.port
         self.putenv("AODH_HTTP_URL", url)
