@@ -19,18 +19,21 @@ import six.moves.urllib.parse as urlparse
 
 from pifpaf import drivers
 from pifpaf.drivers import postgresql
+from pifpaf.drivers import redis
 
 
 class GnocchiDriver(drivers.Driver):
 
     DEFAULT_PORT = 8041
     DEFAULT_PORT_INDEXER = 9541
+    DEFAULT_PORT_COORDINATOR = 9542
 
     def __init__(self, port=DEFAULT_PORT, indexer_port=DEFAULT_PORT_INDEXER,
                  statsd_port=None,
-                 create_legacy_resource_types=False,
                  indexer_url=None,
                  storage_url=None,
+                 coordination_driver="default",
+                 coordination_port=DEFAULT_PORT_COORDINATOR,
                  **kwargs):
         super(GnocchiDriver, self).__init__(**kwargs)
         self.port = port
@@ -38,7 +41,8 @@ class GnocchiDriver(drivers.Driver):
         self.indexer_url = indexer_url
         self.storage_url = storage_url
         self.statsd_port = statsd_port
-        self.create_legacy_resource_types = create_legacy_resource_types
+        self.coordination_driver = coordination_driver
+        self.coordination_port = coordination_port
 
     @classmethod
     def get_parser(cls, parser):
@@ -53,10 +57,15 @@ class GnocchiDriver(drivers.Driver):
                             type=int,
                             default=cls.DEFAULT_PORT_INDEXER,
                             help="port to use for Gnocchi indexer")
-        parser.add_argument("--create-legacy-resource-types",
-                            action='store_true',
-                            default=False,
-                            help="create legacy Ceilometer resource types")
+        parser.add_argument("--coordination-port",
+                            type=int,
+                            default=cls.DEFAULT_PORT_COORDINATOR,
+                            help="port to use for Gnocchi coordination")
+        parser.add_argument("--coordination-driver",
+                            default="default",
+                            choices=["default", "redis"],
+                            nargs="?",
+                            help="Select a coordination driver")
         parser.add_argument("--indexer-url", help="indexer URL to use")
         parser.add_argument("--storage-url", help="storage URL to use")
         return parser
@@ -130,6 +139,10 @@ class GnocchiDriver(drivers.Driver):
             raise RuntimeError("Storage driver %s is not supported" %
                                storage_driver)
 
+        if self.coordination_driver == "redis":
+            r = self.useFixture(redis.RedisDriver(port=self.coordination_port))
+            storage_config["coordination_url"] = r.url
+
         storage_config_string = "\n".join(
             "%s = %s" % (k, v)
             for k, v in storage_config.items()
@@ -137,7 +150,9 @@ class GnocchiDriver(drivers.Driver):
         statsd_resource_id = str(uuid.uuid4())
 
         with open(conffile, "w") as f:
-            f.write("""[storage]
+            f.write("""[DEFAULT]
+debug = %s
+[storage]
 driver = %s
 %s
 [metricd]
@@ -149,15 +164,13 @@ creator = admin
 user_id = admin
 project_id = admin
 [indexer]
-url = %s""" % (storage_driver,
+url = %s""" % (self.debug,
+               storage_driver,
                storage_config_string,
                statsd_resource_id,
                self.indexer_url))
 
-        gnocchi_upgrade = ["gnocchi-upgrade", "--config-file=%s" % conffile]
-        if self.create_legacy_resource_types:
-            gnocchi_upgrade.append("--create-legacy-resource-types")
-        self._exec(gnocchi_upgrade)
+        self._exec(["gnocchi-upgrade", "--config-file=%s" % conffile])
 
         c, _ = self._exec(["gnocchi-metricd", "--config-file=%s" % conffile],
                           wait_for_line="metrics wait to be processed")
